package cn.com.infosec.x509.extension;

import cn.com.infosec.asn1.ASN1Object;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERString;
import cn.com.infosec.asn1.x509.GeneralName;
import cn.com.infosec.asn1.x509.X509Extensions;
import cn.com.infosec.asn1.x509.X509Name;
import java.io.IOException;
import java.security.cert.CertificateParsingException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Enumeration;

public class X509ExtensionUtil {
   public static ASN1Object fromExtensionValue(byte[] encodedValue) {
      return ASN1Object.fromByteArray(((ASN1OctetString)ASN1Object.fromByteArray(encodedValue)).getOctets());
   }

   public static Collection getIssuerAlternativeNames(X509Certificate cert) {
      return getAlternativeName(cert.getExtensionValue(X509Extensions.IssuerAlternativeName.getId()));
   }

   public static Collection getSubjectAlternativeNames(X509Certificate cert) {
      return getAlternativeName(cert.getExtensionValue(X509Extensions.SubjectAlternativeName.getId()));
   }

   private static Collection getAlternativeName(byte[] extVal) {
      ArrayList var1;
      var1 = new ArrayList.<init>();
      if (extVal == null) {
         return Collections.EMPTY_LIST;
      } else {
         Exception var10000;
         label104: {
            boolean var10001;
            Enumeration var21;
            try {
               var21 = ASN1Sequence.getInstance(ASN1Object.fromByteArray(ASN1OctetString.getInstance(ASN1Object.fromByteArray(extVal)).getOctets())).getObjects();
            } catch (Exception var18) {
               var10000 = var18;
               var10001 = false;
               break label104;
            }

            Enumeration extVal1 = var21;

            label95:
            while(true) {
               boolean var22;
               try {
                  var22 = extVal1.hasMoreElements();
               } catch (Exception var11) {
                  var10000 = var11;
                  var10001 = false;
                  break;
               }

               if (!var22) {
                  return Collections.unmodifiableCollection(var1);
               }

               GeneralName var23;
               try {
                  var23 = GeneralName.getInstance(extVal1.nextElement());
               } catch (Exception var10) {
                  var10000 = var10;
                  var10001 = false;
                  break;
               }

               GeneralName var2 = var23;

               ArrayList var24;
               try {
                  var24 = new ArrayList;
               } catch (Exception var9) {
                  var10000 = var9;
                  var10001 = false;
                  break;
               }

               ArrayList var3;
               ArrayList var10002 = var3 = var24;

               try {
                  var10002.<init>();
                  var24.add(new Integer(var2.getTagNo()));
               } catch (Exception var8) {
                  var10000 = var8;
                  var10001 = false;
                  break;
               }

               int var26;
               try {
                  var26 = var23.getTagNo();
               } catch (Exception var7) {
                  var10000 = var7;
                  var10001 = false;
                  break;
               }

               switch (var26) {
                  case 0:
                  case 3:
                  case 5:
                     try {
                        var3.add(var2.getName().getDERObject());
                        break;
                     } catch (Exception var13) {
                        var10000 = var13;
                        var10001 = false;
                        break label95;
                     }
                  case 1:
                  case 2:
                  case 6:
                     try {
                        var3.add(((DERString)var2.getName()).getString());
                        break;
                     } catch (Exception var14) {
                        var10000 = var14;
                        var10001 = false;
                        break label95;
                     }
                  case 4:
                     try {
                        var3.add(X509Name.getInstance(var2.getName()).toString());
                        break;
                     } catch (Exception var15) {
                        var10000 = var15;
                        var10001 = false;
                        break label95;
                     }
                  case 7:
                     try {
                        var3.add(ASN1OctetString.getInstance(var2.getName()).getOctets());
                        break;
                     } catch (Exception var16) {
                        var10000 = var16;
                        var10001 = false;
                        break label95;
                     }
                  case 8:
                     try {
                        var3.add(DERObjectIdentifier.getInstance(var2.getName()).getId());
                        break;
                     } catch (Exception var17) {
                        var10000 = var17;
                        var10001 = false;
                        break label95;
                     }
                  default:
                     IOException var27;
                     try {
                        var27 = new IOException;
                     } catch (Exception var6) {
                        var10000 = var6;
                        var10001 = false;
                        break label95;
                     }

                     StringBuffer var25;
                     IOException var28;
                     try {
                        var28 = var27;
                        var25 = new StringBuffer;
                     } catch (Exception var5) {
                        var10000 = var5;
                        var10001 = false;
                        break label95;
                     }

                     StringBuffer var10003 = var25;

                     try {
                        var10003.<init>("Bad tag number: ");
                        var28.<init>(var25.append(var2.getTagNo()).toString());
                        throw var27;
                     } catch (Exception var4) {
                        var10000 = var4;
                        var10001 = false;
                        break label95;
                     }
               }

               try {
                  var1.add(var3);
               } catch (Exception var12) {
                  var10000 = var12;
                  var10001 = false;
                  break;
               }
            }
         }

         Exception extVal2 = var10000;
         throw new CertificateParsingException(extVal2.getMessage());
      }
   }
}
